# Generated by roxygen2: do not edit by hand

export(create_link_registry)
export(link_plots)
export(prepare_plotly_linking)
export(process_sf_data)
export(register_dt)
export(register_leaflet)
export(register_plotly)
importFrom(magrittr,"%>%")
importFrom(shiny,is.reactive)
importFrom(shiny,isolate)
importFrom(shiny,observeEvent)
importFrom(shiny,reactive)
importFrom(shiny,reactiveValues)
importFrom(shiny,req)
importFrom(stats,as.formula)
